# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: condition/condition_futures.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from trade import trade_enum_pb2 as trade_dot_trade__enum__pb2
from trade import trade_pb2 as trade_dot_trade__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='condition/condition_futures.proto',
    package='condition.futures',
    syntax='proto3',
    serialized_options=_b('\242\002\003CFT'),
    serialized_pb=_b(
        '\n!condition/condition_futures.proto\x12\x11\x63ondition.futures\x1a\x16trade/trade_enum.proto\x1a\x11trade/trade.proto\"\xa8\x07\n\rConditionInfo\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x15\n\rinstrument_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x04 \x01(\t\x12(\n\tdirection\x18\x05 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x06 \x01(\t\x12\x33\n\x10order_price_type\x18\x07 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x08 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\t \x01(\r\x12.\n\tinit_flag\x18\n \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x1a\n\x12valid_period_count\x18\x0b \x01(\r\x12\x11\n\tcondition\x18\x0c \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\r \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\x0e \x01(\t\x12\x38\n\x10\x63ondition_status\x18\x0f \x01(\x0e\x32\x1e.trade.tag.ConditionStatusType\x12\x12\n\nstatus_msg\x18\x10 \x01(\x0c\x12\x0f\n\x07message\x18\x11 \x01(\x0c\x12\x13\n\x0binsert_time\x18\x12 \x01(\t\x12\x15\n\ractivate_time\x18\x13 \x01(\t\x12\x13\n\x0bmodify_time\x18\x14 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x15 \x01(\t\x12\x12\n\npause_time\x18\x16 \x01(\t\x12\x14\n\x0ctrigger_time\x18\x17 \x01(\t\x12\x17\n\x0ftrigger_hq_time\x18\x18 \x01(\t\x12\x14\n\x0ctrigger_tips\x18\x19 \x01(\t\x12\x1d\n\x15trigger_entrust_price\x18\x1a \x01(\x01\x12\x1e\n\x16trigger_entrust_amount\x18\x1b \x01(\x05\x12\x13\n\x0binvestor_id\x18\x1c \x01(\t\x12\x11\n\tbroker_id\x18\x1d \x01(\t\x12,\n\x0einterface_type\x18\x1e \x01(\x0e\x32\x14.trade.InterfaceType\x12\x13\n\x0b\x65xpire_date\x18\x1f \x01(\x05\x12%\n\x06source\x18  \x01(\x0e\x32\x15.trade.tag.SourceType\x12\x14\n\x0cpre_order_no\x18! \x01(\t\x12\x15\n\rtrigger_price\x18\" \x01(\x01\"\xa1\x07\n\x06Report\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x15\n\rinstrument_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x04 \x01(\t\x12(\n\tdirection\x18\x05 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x06 \x01(\t\x12\x33\n\x10order_price_type\x18\x07 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x08 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\t \x01(\r\x12.\n\tinit_flag\x18\n \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x1a\n\x12valid_period_count\x18\x0b \x01(\r\x12\x11\n\tcondition\x18\x0c \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\r \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\x0e \x01(\t\x12\x38\n\x10\x63ondition_status\x18\x0f \x01(\x0e\x32\x1e.trade.tag.ConditionStatusType\x12\x12\n\nstatus_msg\x18\x10 \x01(\x0c\x12\x0f\n\x07message\x18\x11 \x01(\x0c\x12\x13\n\x0binsert_time\x18\x12 \x01(\t\x12\x15\n\ractivate_time\x18\x13 \x01(\t\x12\x13\n\x0bmodify_time\x18\x14 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x15 \x01(\t\x12\x12\n\npause_time\x18\x16 \x01(\t\x12\x14\n\x0ctrigger_time\x18\x17 \x01(\t\x12\x17\n\x0ftrigger_hq_time\x18\x18 \x01(\t\x12\x14\n\x0ctrigger_tips\x18\x19 \x01(\t\x12\x1d\n\x15trigger_entrust_price\x18\x1a \x01(\x01\x12\x1e\n\x16trigger_entrust_amount\x18\x1b \x01(\r\x12\x13\n\x0binvestor_id\x18\x1c \x01(\t\x12\x11\n\tbroker_id\x18\x1d \x01(\t\x12,\n\x0einterface_type\x18\x1e \x01(\x0e\x32\x14.trade.InterfaceType\x12\x13\n\x0b\x65xpire_date\x18\x1f \x01(\x05\x12%\n\x06source\x18  \x01(\x0e\x32\x15.trade.tag.SourceType\x12\x14\n\x0cpre_order_no\x18! \x01(\t\x12\x15\n\rtrigger_price\x18\" \x01(\x01\"\x9c\x04\n\tInsertReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12(\n\tdirection\x18\x04 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x05 \x01(\t\x12\x33\n\x10order_price_type\x18\x06 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x07 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\x08 \x01(\r\x12.\n\tinit_flag\x18\t \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x1a\n\x12valid_period_count\x18\n \x01(\r\x12\x11\n\tcondition\x18\x0b \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x0c \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\r \x01(\t\x12\x13\n\x0binvestor_id\x18\x0e \x01(\t\x12\x11\n\tbroker_id\x18\x0f \x01(\t\x12,\n\x0einterface_type\x18\x10 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x11 \x01(\x0e\x32\x15.trade.tag.SourceType\x12\x14\n\x0cpre_order_no\x18\x12 \x01(\t\"6\n\tInsertRsp\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x19.condition.futures.Report\"\xdd\x03\n\tModifyReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12.\n\tinit_flag\x18\x03 \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x33\n\x10order_price_type\x18\x05 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x06 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\x08 \x01(\r\x12\x1a\n\x12valid_period_count\x18\t \x01(\r\x12\x11\n\tcondition\x18\n \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x0b \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\x0c \x01(\t\x12\x13\n\x0binvestor_id\x18\r \x01(\t\x12(\n\tdirection\x18\x0e \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x0f \x01(\t\x12%\n\x06source\x18\x10 \x01(\x0e\x32\x15.trade.tag.SourceType\x12\x14\n\x0cpre_order_no\x18\x11 \x01(\t\x12\x1a\n\x12modify_preorder_no\x18\x12 \x01(\x08\"6\n\tModifyRsp\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x19.condition.futures.Report\"n\n\x08PauseReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12%\n\x06source\x18\x04 \x01(\x0e\x32\x15.trade.tag.SourceType\"5\n\x08PauseRsp\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x19.condition.futures.Report\"q\n\x0b\x41\x63tivateReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12%\n\x06source\x18\x04 \x01(\x0e\x32\x15.trade.tag.SourceType\"8\n\x0b\x41\x63tivateRsp\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x19.condition.futures.Report\"o\n\tDeleteReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12%\n\x06source\x18\x04 \x01(\x0e\x32\x15.trade.tag.SourceType\"6\n\tDeleteRsp\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x19.condition.futures.Report\"o\n\tCancelReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12%\n\x06source\x18\x04 \x01(\x0e\x32\x15.trade.tag.SourceType\"6\n\tCancelRsp\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x19.condition.futures.Report\"\xa6\x02\n\x08QueryReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x12\n\nstart_date\x18\x03 \x01(\r\x12\x10\n\x08\x65nd_date\x18\x04 \x01(\r\x12\x16\n\x0e\x63ondition_type\x18\x05 \x01(\r\x12\x38\n\x10\x63ondition_status\x18\x06 \x01(\x0e\x32\x1e.trade.tag.ConditionStatusType\x12\x13\n\x0binvestor_id\x18\x07 \x01(\t\x12\x11\n\tbroker_id\x18\x08 \x01(\t\x12,\n\x0einterface_type\x18\t \x01(\x0e\x32\x14.trade.InterfaceType\x12\x12\n\nbegin_time\x18\n \x01(\t\x12\x10\n\x08\x65nd_time\x18\x0b \x01(\t\"5\n\x08QueryRsp\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x19.condition.futures.Report\";\n\rMultiQueryRsp\x12*\n\x07results\x18\x02 \x03(\x0b\x32\x19.condition.futures.Report\"\xbc\x01\n\rConditionPush\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x14\n\x0c\x63ondition_no\x18\x02 \x01(\t\x12\x15\n\rinstrument_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x04 \x01(\t\x12\x13\n\x0btrading_day\x18\x05 \x01(\t\x12\x14\n\x0corder_sys_id\x18\x06 \x01(\t\x12(\n\tdirection\x18\x07 \x01(\x0e\x32\x15.trade.tag.ActionType\">\n\x0f\x43onditionSettle\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.condition.futures.SettleFlag\"A\n\x12\x43onditionSettleRsp\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.condition.futures.SettleFlag*1\n\x08InitFlag\x12\x11\n\rInitFlag_Init\x10\x00\x12\x12\n\x0eInitFlag_Pause\x10\x01*Q\n\nSettleFlag\x12\x17\n\x13SettleFlag_Undefine\x10\x00\x12\x13\n\x0fSettleFlag_Init\x10\x01\x12\x15\n\x11SettleFlag_Settle\x10\x02\x42\x06\xa2\x02\x03\x43\x46Tb\x06proto3')
    ,
    dependencies=[trade_dot_trade__enum__pb2.DESCRIPTOR, trade_dot_trade__pb2.DESCRIPTOR, ])

_INITFLAG = _descriptor.EnumDescriptor(
    name='InitFlag',
    full_name='condition.futures.InitFlag',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='InitFlag_Init', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='InitFlag_Pause', index=1, number=1,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4518,
    serialized_end=4567,
)
_sym_db.RegisterEnumDescriptor(_INITFLAG)

InitFlag = enum_type_wrapper.EnumTypeWrapper(_INITFLAG)
_SETTLEFLAG = _descriptor.EnumDescriptor(
    name='SettleFlag',
    full_name='condition.futures.SettleFlag',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='SettleFlag_Undefine', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='SettleFlag_Init', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='SettleFlag_Settle', index=2, number=2,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4569,
    serialized_end=4650,
)
_sym_db.RegisterEnumDescriptor(_SETTLEFLAG)

SettleFlag = enum_type_wrapper.EnumTypeWrapper(_SETTLEFLAG)
InitFlag_Init = 0
InitFlag_Pause = 1
SettleFlag_Undefine = 0
SettleFlag_Init = 1
SettleFlag_Settle = 2

_CONDITIONINFO = _descriptor.Descriptor(
    name='ConditionInfo',
    full_name='condition.futures.ConditionInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.ConditionInfo.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.ConditionInfo.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='condition.futures.ConditionInfo.instrument_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='condition.futures.ConditionInfo.exchange_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='condition.futures.ConditionInfo.direction', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='condition.futures.ConditionInfo.comb_offset_flag', index=5,
            number=6, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='condition.futures.ConditionInfo.order_price_type', index=6,
            number=7, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='condition.futures.ConditionInfo.limit_price', index=7,
            number=8, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='condition.futures.ConditionInfo.volume_total_original', index=8,
            number=9, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='condition.futures.ConditionInfo.init_flag', index=9,
            number=10, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='condition.futures.ConditionInfo.valid_period_count', index=10,
            number=11, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='condition.futures.ConditionInfo.condition', index=11,
            number=12, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='condition.futures.ConditionInfo.condition_type', index=12,
            number=13, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='condition.futures.ConditionInfo.condition_info', index=13,
            number=14, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_status', full_name='condition.futures.ConditionInfo.condition_status', index=14,
            number=15, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status_msg', full_name='condition.futures.ConditionInfo.status_msg', index=15,
            number=16, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='message', full_name='condition.futures.ConditionInfo.message', index=16,
            number=17, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='insert_time', full_name='condition.futures.ConditionInfo.insert_time', index=17,
            number=18, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='activate_time', full_name='condition.futures.ConditionInfo.activate_time', index=18,
            number=19, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='modify_time', full_name='condition.futures.ConditionInfo.modify_time', index=19,
            number=20, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_time', full_name='condition.futures.ConditionInfo.end_time', index=20,
            number=21, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='pause_time', full_name='condition.futures.ConditionInfo.pause_time', index=21,
            number=22, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_time', full_name='condition.futures.ConditionInfo.trigger_time', index=22,
            number=23, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_hq_time', full_name='condition.futures.ConditionInfo.trigger_hq_time', index=23,
            number=24, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_tips', full_name='condition.futures.ConditionInfo.trigger_tips', index=24,
            number=25, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_entrust_price', full_name='condition.futures.ConditionInfo.trigger_entrust_price', index=25,
            number=26, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_entrust_amount', full_name='condition.futures.ConditionInfo.trigger_entrust_amount', index=26,
            number=27, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.ConditionInfo.investor_id', index=27,
            number=28, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='condition.futures.ConditionInfo.broker_id', index=28,
            number=29, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='condition.futures.ConditionInfo.interface_type', index=29,
            number=30, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='expire_date', full_name='condition.futures.ConditionInfo.expire_date', index=30,
            number=31, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.ConditionInfo.source', index=31,
            number=32, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='pre_order_no', full_name='condition.futures.ConditionInfo.pre_order_no', index=32,
            number=33, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_price', full_name='condition.futures.ConditionInfo.trigger_price', index=33,
            number=34, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=100,
    serialized_end=1036,
)

_REPORT = _descriptor.Descriptor(
    name='Report',
    full_name='condition.futures.Report',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.Report.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.Report.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='condition.futures.Report.instrument_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='condition.futures.Report.exchange_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='condition.futures.Report.direction', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='condition.futures.Report.comb_offset_flag', index=5,
            number=6, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='condition.futures.Report.order_price_type', index=6,
            number=7, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='condition.futures.Report.limit_price', index=7,
            number=8, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='condition.futures.Report.volume_total_original', index=8,
            number=9, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='condition.futures.Report.init_flag', index=9,
            number=10, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='condition.futures.Report.valid_period_count', index=10,
            number=11, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='condition.futures.Report.condition', index=11,
            number=12, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='condition.futures.Report.condition_type', index=12,
            number=13, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='condition.futures.Report.condition_info', index=13,
            number=14, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_status', full_name='condition.futures.Report.condition_status', index=14,
            number=15, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status_msg', full_name='condition.futures.Report.status_msg', index=15,
            number=16, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='message', full_name='condition.futures.Report.message', index=16,
            number=17, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='insert_time', full_name='condition.futures.Report.insert_time', index=17,
            number=18, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='activate_time', full_name='condition.futures.Report.activate_time', index=18,
            number=19, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='modify_time', full_name='condition.futures.Report.modify_time', index=19,
            number=20, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_time', full_name='condition.futures.Report.end_time', index=20,
            number=21, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='pause_time', full_name='condition.futures.Report.pause_time', index=21,
            number=22, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_time', full_name='condition.futures.Report.trigger_time', index=22,
            number=23, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_hq_time', full_name='condition.futures.Report.trigger_hq_time', index=23,
            number=24, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_tips', full_name='condition.futures.Report.trigger_tips', index=24,
            number=25, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_entrust_price', full_name='condition.futures.Report.trigger_entrust_price', index=25,
            number=26, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_entrust_amount', full_name='condition.futures.Report.trigger_entrust_amount', index=26,
            number=27, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.Report.investor_id', index=27,
            number=28, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='condition.futures.Report.broker_id', index=28,
            number=29, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='condition.futures.Report.interface_type', index=29,
            number=30, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='expire_date', full_name='condition.futures.Report.expire_date', index=30,
            number=31, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.Report.source', index=31,
            number=32, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='pre_order_no', full_name='condition.futures.Report.pre_order_no', index=32,
            number=33, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trigger_price', full_name='condition.futures.Report.trigger_price', index=33,
            number=34, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1039,
    serialized_end=1968,
)

_INSERTREQ = _descriptor.Descriptor(
    name='InsertReq',
    full_name='condition.futures.InsertReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.InsertReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='condition.futures.InsertReq.instrument_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='condition.futures.InsertReq.exchange_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='condition.futures.InsertReq.direction', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='condition.futures.InsertReq.comb_offset_flag', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='condition.futures.InsertReq.order_price_type', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='condition.futures.InsertReq.limit_price', index=6,
            number=7, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='condition.futures.InsertReq.volume_total_original', index=7,
            number=8, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='condition.futures.InsertReq.init_flag', index=8,
            number=9, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='condition.futures.InsertReq.valid_period_count', index=9,
            number=10, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='condition.futures.InsertReq.condition', index=10,
            number=11, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='condition.futures.InsertReq.condition_type', index=11,
            number=12, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='condition.futures.InsertReq.condition_info', index=12,
            number=13, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.InsertReq.investor_id', index=13,
            number=14, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='condition.futures.InsertReq.broker_id', index=14,
            number=15, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='condition.futures.InsertReq.interface_type', index=15,
            number=16, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.InsertReq.source', index=16,
            number=17, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='pre_order_no', full_name='condition.futures.InsertReq.pre_order_no', index=17,
            number=18, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1971,
    serialized_end=2511,
)

_INSERTRSP = _descriptor.Descriptor(
    name='InsertRsp',
    full_name='condition.futures.InsertRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='result', full_name='condition.futures.InsertRsp.result', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2513,
    serialized_end=2567,
)

_MODIFYREQ = _descriptor.Descriptor(
    name='ModifyReq',
    full_name='condition.futures.ModifyReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.ModifyReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.ModifyReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='condition.futures.ModifyReq.init_flag', index=2,
            number=3, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='condition.futures.ModifyReq.order_price_type', index=3,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='condition.futures.ModifyReq.limit_price', index=4,
            number=6, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='condition.futures.ModifyReq.volume_total_original', index=5,
            number=8, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='condition.futures.ModifyReq.valid_period_count', index=6,
            number=9, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='condition.futures.ModifyReq.condition', index=7,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='condition.futures.ModifyReq.condition_type', index=8,
            number=11, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='condition.futures.ModifyReq.condition_info', index=9,
            number=12, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.ModifyReq.investor_id', index=10,
            number=13, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='condition.futures.ModifyReq.direction', index=11,
            number=14, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='condition.futures.ModifyReq.comb_offset_flag', index=12,
            number=15, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.ModifyReq.source', index=13,
            number=16, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='pre_order_no', full_name='condition.futures.ModifyReq.pre_order_no', index=14,
            number=17, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='modify_preorder_no', full_name='condition.futures.ModifyReq.modify_preorder_no', index=15,
            number=18, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2570,
    serialized_end=3047,
)

_MODIFYRSP = _descriptor.Descriptor(
    name='ModifyRsp',
    full_name='condition.futures.ModifyRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='result', full_name='condition.futures.ModifyRsp.result', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3049,
    serialized_end=3103,
)

_PAUSEREQ = _descriptor.Descriptor(
    name='PauseReq',
    full_name='condition.futures.PauseReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.PauseReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.PauseReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.PauseReq.investor_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.PauseReq.source', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3105,
    serialized_end=3215,
)

_PAUSERSP = _descriptor.Descriptor(
    name='PauseRsp',
    full_name='condition.futures.PauseRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='result', full_name='condition.futures.PauseRsp.result', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3217,
    serialized_end=3270,
)

_ACTIVATEREQ = _descriptor.Descriptor(
    name='ActivateReq',
    full_name='condition.futures.ActivateReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.ActivateReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.ActivateReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.ActivateReq.investor_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.ActivateReq.source', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3272,
    serialized_end=3385,
)

_ACTIVATERSP = _descriptor.Descriptor(
    name='ActivateRsp',
    full_name='condition.futures.ActivateRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='result', full_name='condition.futures.ActivateRsp.result', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3387,
    serialized_end=3443,
)

_DELETEREQ = _descriptor.Descriptor(
    name='DeleteReq',
    full_name='condition.futures.DeleteReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.DeleteReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.DeleteReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.DeleteReq.investor_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.DeleteReq.source', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3445,
    serialized_end=3556,
)

_DELETERSP = _descriptor.Descriptor(
    name='DeleteRsp',
    full_name='condition.futures.DeleteRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='result', full_name='condition.futures.DeleteRsp.result', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3558,
    serialized_end=3612,
)

_CANCELREQ = _descriptor.Descriptor(
    name='CancelReq',
    full_name='condition.futures.CancelReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.CancelReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.CancelReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.CancelReq.investor_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='condition.futures.CancelReq.source', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3614,
    serialized_end=3725,
)

_CANCELRSP = _descriptor.Descriptor(
    name='CancelRsp',
    full_name='condition.futures.CancelRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='result', full_name='condition.futures.CancelRsp.result', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3727,
    serialized_end=3781,
)

_QUERYREQ = _descriptor.Descriptor(
    name='QueryReq',
    full_name='condition.futures.QueryReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.QueryReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='condition.futures.QueryReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='start_date', full_name='condition.futures.QueryReq.start_date', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_date', full_name='condition.futures.QueryReq.end_date', index=3,
            number=4, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='condition.futures.QueryReq.condition_type', index=4,
            number=5, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_status', full_name='condition.futures.QueryReq.condition_status', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='condition.futures.QueryReq.investor_id', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='condition.futures.QueryReq.broker_id', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='condition.futures.QueryReq.interface_type', index=8,
            number=9, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='begin_time', full_name='condition.futures.QueryReq.begin_time', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_time', full_name='condition.futures.QueryReq.end_time', index=10,
            number=11, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3784,
    serialized_end=4078,
)

_QUERYRSP = _descriptor.Descriptor(
    name='QueryRsp',
    full_name='condition.futures.QueryRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='result', full_name='condition.futures.QueryRsp.result', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4080,
    serialized_end=4133,
)

_MULTIQUERYRSP = _descriptor.Descriptor(
    name='MultiQueryRsp',
    full_name='condition.futures.MultiQueryRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='results', full_name='condition.futures.MultiQueryRsp.results', index=0,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4135,
    serialized_end=4194,
)

_CONDITIONPUSH = _descriptor.Descriptor(
    name='ConditionPush',
    full_name='condition.futures.ConditionPush',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='condition.futures.ConditionPush.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_no', full_name='condition.futures.ConditionPush.condition_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='condition.futures.ConditionPush.instrument_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='condition.futures.ConditionPush.exchange_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='trading_day', full_name='condition.futures.ConditionPush.trading_day', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_sys_id', full_name='condition.futures.ConditionPush.order_sys_id', index=5,
            number=6, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='condition.futures.ConditionPush.direction', index=6,
            number=7, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4197,
    serialized_end=4385,
)

_CONDITIONSETTLE = _descriptor.Descriptor(
    name='ConditionSettle',
    full_name='condition.futures.ConditionSettle',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='condition.futures.ConditionSettle.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4387,
    serialized_end=4449,
)

_CONDITIONSETTLERSP = _descriptor.Descriptor(
    name='ConditionSettleRsp',
    full_name='condition.futures.ConditionSettleRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='condition.futures.ConditionSettleRsp.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4451,
    serialized_end=4516,
)

_CONDITIONINFO.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_CONDITIONINFO.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_CONDITIONINFO.fields_by_name['init_flag'].enum_type = _INITFLAG
_CONDITIONINFO.fields_by_name['condition_status'].enum_type = trade_dot_trade__enum__pb2._CONDITIONSTATUSTYPE
_CONDITIONINFO.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_CONDITIONINFO.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_REPORT.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_REPORT.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_REPORT.fields_by_name['init_flag'].enum_type = _INITFLAG
_REPORT.fields_by_name['condition_status'].enum_type = trade_dot_trade__enum__pb2._CONDITIONSTATUSTYPE
_REPORT.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_REPORT.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_INSERTREQ.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_INSERTREQ.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_INSERTREQ.fields_by_name['init_flag'].enum_type = _INITFLAG
_INSERTREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_INSERTREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_INSERTRSP.fields_by_name['result'].message_type = _REPORT
_MODIFYREQ.fields_by_name['init_flag'].enum_type = _INITFLAG
_MODIFYREQ.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_MODIFYREQ.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_MODIFYREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_MODIFYRSP.fields_by_name['result'].message_type = _REPORT
_PAUSEREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_PAUSERSP.fields_by_name['result'].message_type = _REPORT
_ACTIVATEREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_ACTIVATERSP.fields_by_name['result'].message_type = _REPORT
_DELETEREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_DELETERSP.fields_by_name['result'].message_type = _REPORT
_CANCELREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_CANCELRSP.fields_by_name['result'].message_type = _REPORT
_QUERYREQ.fields_by_name['condition_status'].enum_type = trade_dot_trade__enum__pb2._CONDITIONSTATUSTYPE
_QUERYREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_QUERYRSP.fields_by_name['result'].message_type = _REPORT
_MULTIQUERYRSP.fields_by_name['results'].message_type = _REPORT
_CONDITIONPUSH.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_CONDITIONSETTLE.fields_by_name['type'].enum_type = _SETTLEFLAG
_CONDITIONSETTLERSP.fields_by_name['type'].enum_type = _SETTLEFLAG
DESCRIPTOR.message_types_by_name['ConditionInfo'] = _CONDITIONINFO
DESCRIPTOR.message_types_by_name['Report'] = _REPORT
DESCRIPTOR.message_types_by_name['InsertReq'] = _INSERTREQ
DESCRIPTOR.message_types_by_name['InsertRsp'] = _INSERTRSP
DESCRIPTOR.message_types_by_name['ModifyReq'] = _MODIFYREQ
DESCRIPTOR.message_types_by_name['ModifyRsp'] = _MODIFYRSP
DESCRIPTOR.message_types_by_name['PauseReq'] = _PAUSEREQ
DESCRIPTOR.message_types_by_name['PauseRsp'] = _PAUSERSP
DESCRIPTOR.message_types_by_name['ActivateReq'] = _ACTIVATEREQ
DESCRIPTOR.message_types_by_name['ActivateRsp'] = _ACTIVATERSP
DESCRIPTOR.message_types_by_name['DeleteReq'] = _DELETEREQ
DESCRIPTOR.message_types_by_name['DeleteRsp'] = _DELETERSP
DESCRIPTOR.message_types_by_name['CancelReq'] = _CANCELREQ
DESCRIPTOR.message_types_by_name['CancelRsp'] = _CANCELRSP
DESCRIPTOR.message_types_by_name['QueryReq'] = _QUERYREQ
DESCRIPTOR.message_types_by_name['QueryRsp'] = _QUERYRSP
DESCRIPTOR.message_types_by_name['MultiQueryRsp'] = _MULTIQUERYRSP
DESCRIPTOR.message_types_by_name['ConditionPush'] = _CONDITIONPUSH
DESCRIPTOR.message_types_by_name['ConditionSettle'] = _CONDITIONSETTLE
DESCRIPTOR.message_types_by_name['ConditionSettleRsp'] = _CONDITIONSETTLERSP
DESCRIPTOR.enum_types_by_name['InitFlag'] = _INITFLAG
DESCRIPTOR.enum_types_by_name['SettleFlag'] = _SETTLEFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConditionInfo = _reflection.GeneratedProtocolMessageType('ConditionInfo', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONINFO,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ConditionInfo)
})
_sym_db.RegisterMessage(ConditionInfo)

Report = _reflection.GeneratedProtocolMessageType('Report', (_message.Message,), {
    'DESCRIPTOR': _REPORT,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.Report)
})
_sym_db.RegisterMessage(Report)

InsertReq = _reflection.GeneratedProtocolMessageType('InsertReq', (_message.Message,), {
    'DESCRIPTOR': _INSERTREQ,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.InsertReq)
})
_sym_db.RegisterMessage(InsertReq)

InsertRsp = _reflection.GeneratedProtocolMessageType('InsertRsp', (_message.Message,), {
    'DESCRIPTOR': _INSERTRSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.InsertRsp)
})
_sym_db.RegisterMessage(InsertRsp)

ModifyReq = _reflection.GeneratedProtocolMessageType('ModifyReq', (_message.Message,), {
    'DESCRIPTOR': _MODIFYREQ,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ModifyReq)
})
_sym_db.RegisterMessage(ModifyReq)

ModifyRsp = _reflection.GeneratedProtocolMessageType('ModifyRsp', (_message.Message,), {
    'DESCRIPTOR': _MODIFYRSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ModifyRsp)
})
_sym_db.RegisterMessage(ModifyRsp)

PauseReq = _reflection.GeneratedProtocolMessageType('PauseReq', (_message.Message,), {
    'DESCRIPTOR': _PAUSEREQ,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.PauseReq)
})
_sym_db.RegisterMessage(PauseReq)

PauseRsp = _reflection.GeneratedProtocolMessageType('PauseRsp', (_message.Message,), {
    'DESCRIPTOR': _PAUSERSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.PauseRsp)
})
_sym_db.RegisterMessage(PauseRsp)

ActivateReq = _reflection.GeneratedProtocolMessageType('ActivateReq', (_message.Message,), {
    'DESCRIPTOR': _ACTIVATEREQ,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ActivateReq)
})
_sym_db.RegisterMessage(ActivateReq)

ActivateRsp = _reflection.GeneratedProtocolMessageType('ActivateRsp', (_message.Message,), {
    'DESCRIPTOR': _ACTIVATERSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ActivateRsp)
})
_sym_db.RegisterMessage(ActivateRsp)

DeleteReq = _reflection.GeneratedProtocolMessageType('DeleteReq', (_message.Message,), {
    'DESCRIPTOR': _DELETEREQ,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.DeleteReq)
})
_sym_db.RegisterMessage(DeleteReq)

DeleteRsp = _reflection.GeneratedProtocolMessageType('DeleteRsp', (_message.Message,), {
    'DESCRIPTOR': _DELETERSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.DeleteRsp)
})
_sym_db.RegisterMessage(DeleteRsp)

CancelReq = _reflection.GeneratedProtocolMessageType('CancelReq', (_message.Message,), {
    'DESCRIPTOR': _CANCELREQ,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.CancelReq)
})
_sym_db.RegisterMessage(CancelReq)

CancelRsp = _reflection.GeneratedProtocolMessageType('CancelRsp', (_message.Message,), {
    'DESCRIPTOR': _CANCELRSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.CancelRsp)
})
_sym_db.RegisterMessage(CancelRsp)

QueryReq = _reflection.GeneratedProtocolMessageType('QueryReq', (_message.Message,), {
    'DESCRIPTOR': _QUERYREQ,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.QueryReq)
})
_sym_db.RegisterMessage(QueryReq)

QueryRsp = _reflection.GeneratedProtocolMessageType('QueryRsp', (_message.Message,), {
    'DESCRIPTOR': _QUERYRSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.QueryRsp)
})
_sym_db.RegisterMessage(QueryRsp)

MultiQueryRsp = _reflection.GeneratedProtocolMessageType('MultiQueryRsp', (_message.Message,), {
    'DESCRIPTOR': _MULTIQUERYRSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.MultiQueryRsp)
})
_sym_db.RegisterMessage(MultiQueryRsp)

ConditionPush = _reflection.GeneratedProtocolMessageType('ConditionPush', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONPUSH,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ConditionPush)
})
_sym_db.RegisterMessage(ConditionPush)

ConditionSettle = _reflection.GeneratedProtocolMessageType('ConditionSettle', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONSETTLE,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ConditionSettle)
})
_sym_db.RegisterMessage(ConditionSettle)

ConditionSettleRsp = _reflection.GeneratedProtocolMessageType('ConditionSettleRsp', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONSETTLERSP,
    '__module__': 'condition.condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:condition.futures.ConditionSettleRsp)
})
_sym_db.RegisterMessage(ConditionSettleRsp)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
